==> AsposeCellsCloud-CellsApi-23.7.tar.gz: AsposeCellsCloud-CellsApi-23.7/lib/AsposeCellsCloud/Object/BatchSplitRequest.pm <==
=begin comment

Copyright (c) 2023 Aspose.Cells Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

=end comment

=cut

package AsposeCellsCloud::Object::BatchSplitRequest;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;
use AsposeCellsCloud::Object::MatchConditionRequest;
use AsposeCellsCloud::Object::SaveOptions; 


use base ("Class::Accessor", "Class::Data::Inheritable");



__PACKAGE__->mk_classdata('attribute_map' => {});
__PACKAGE__->mk_classdata('swagger_types' => {});
__PACKAGE__->mk_classdata('method_documentation' => {}); 
__PACKAGE__->mk_classdata('class_documentation' => {});

# new object
sub new { 
    my ($class, %args) = @_; 

	my $self = bless {}, $class;

	foreach my $attribute (keys %{$class->attribute_map}) {
		my $args_key = $class->attribute_map->{$attribute};
		$self->$attribute( $args{ $args_key } );
	}

	return $self;
}  

# return perl hash
sub to_hash {
    return decode_json(JSON->new->convert_blessed->encode( shift ));
}

# used by JSON for serialization
sub TO_JSON { 
    my $self = shift;
    my $_data = {};
    foreach my $_key (keys %{$self->attribute_map}) {
        if (defined $self->{$_key}) {
            $_data->{$self->attribute_map->{$_key}} = $self->{$_key};
        }
    }
    return $_data;
}

# from Perl hashref
sub from_hash {
    my ($self, $hash) = @_;

    # loop through attributes and use swagger_types to deserialize the data
    while ( my ($_key, $_type) = each %{$self->swagger_types} ) {
    	my $_json_attribute = $self->attribute_map->{$_key}; 
        if ($_type =~ /^array\[/i) { # array
            my $_subclass = substr($_type, 6, -1);
            my @_array = ();
            foreach my $_element (@{$hash->{$_json_attribute}}) {
                push @_array, $self->_deserialize($_subclass, $_element);
            }
            $self->{$_key} = \@_array;
        } elsif (exists $hash->{$_json_attribute}) { #hash(model), primitive, datetime
            $self->{$_key} = $self->_deserialize($_type, $hash->{$_json_attribute});
        } else {
        	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
        }
    }

    return $self;
}

# deserialize non-array data
sub _deserialize {
    my ($self, $type, $data) = @_;
    $log->debugf("deserializing %s with %s",Dumper($data), $type);

    if ($type eq 'DateTime') {
        return DateTime->from_epoch(epoch => str2time($data));
    } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
        return $data;
    } else { # hash(model)
        my $_instance = eval "AsposeCellsCloud::Object::$type->new()";
        return $_instance->from_hash($data);
    }
}


__PACKAGE__->class_documentation({description => '',
                                  class => 'BatchSplitRequest',
                                  required => [], # TODO
}                                 );


__PACKAGE__->method_documentation({
     'source_folder' => {
     	datatype => 'string',
     	base_name => 'SourceFolder',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'source_storage' => {
     	datatype => 'string',
     	base_name => 'SourceStorage',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'match_condition' => {
     	datatype => 'MatchConditionRequest',
     	base_name => 'MatchCondition',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'format' => {
     	datatype => 'string',
     	base_name => 'Format',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'from_index' => {
     	datatype => 'int',
     	base_name => 'FromIndex',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'to_index' => {
     	datatype => 'int',
     	base_name => 'ToIndex',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'out_folder' => {
     	datatype => 'string',
     	base_name => 'OutFolder',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'out_storage' => {
     	datatype => 'string',
     	base_name => 'OutStorage',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'save_options' => {
     	datatype => 'SaveOptions',
     	base_name => 'SaveOptions',
     	description => '',
     	format => '',
     	read_only => '',
     		},    
});

__PACKAGE__->swagger_types( {
    'source_folder' => 'string',
    'source_storage' => 'string',
    'match_condition' => 'MatchConditionRequest',
    'format' => 'string',
    'from_index' => 'int',
    'to_index' => 'int',
    'out_folder' => 'string',
    'out_storage' => 'string',
    'save_options' => 'SaveOptions' 
} );

__PACKAGE__->attribute_map( {
    'source_folder' => 'SourceFolder',
    'source_storage' => 'SourceStorage',
    'match_condition' => 'MatchCondition',
    'format' => 'Format',
    'from_index' => 'FromIndex',
    'to_index' => 'ToIndex',
    'out_folder' => 'OutFolder',
    'out_storage' => 'OutStorage',
    'save_options' => 'SaveOptions' 
} );

__PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});


1;

==> AsposeCellsCloud-CellsApi-23.10.tar.gz: AsposeCellsCloud-CellsApi-23.10/lib/AsposeCellsCloud/Object/BatchSplitRequest.pm <==
=begin comment

Copyright (c) 2023 Aspose.Cells Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

=end comment

=cut

package AsposeCellsCloud::Object::BatchSplitRequest;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;
use AsposeCellsCloud::Object::MatchConditionRequest;
use AsposeCellsCloud::Object::SaveOptions; 


use base ("Class::Accessor", "Class::Data::Inheritable");



__PACKAGE__->mk_classdata('attribute_map' => {});
__PACKAGE__->mk_classdata('swagger_types' => {});
__PACKAGE__->mk_classdata('method_documentation' => {}); 
__PACKAGE__->mk_classdata('class_documentation' => {});

# new object
sub new { 
    my ($class, %args) = @_; 

	my $self = bless {}, $class;

	foreach my $attribute (keys %{$class->attribute_map}) {
		my $args_key = $class->attribute_map->{$attribute};
		$self->$attribute( $args{ $args_key } );
	}

	return $self;
}  

# return perl hash
sub to_hash {
    return decode_json(JSON->new->convert_blessed->encode( shift ));
}

# used by JSON for serialization
sub TO_JSON { 
    my $self = shift;
    my $_data = {};
    foreach my $_key (keys %{$self->attribute_map}) {
        if (defined $self->{$_key}) {
            $_data->{$self->attribute_map->{$_key}} = $self->{$_key};
        }
    }
    return $_data;
}

# from Perl hashref
sub from_hash {
    my ($self, $hash) = @_;

    # loop through attributes and use swagger_types to deserialize the data
    while ( my ($_key, $_type) = each %{$self->swagger_types} ) {
    	my $_json_attribute = $self->attribute_map->{$_key}; 
        if ($_type =~ /^array\[/i) { # array
            my $_subclass = substr($_type, 6, -1);
            my @_array = ();
            foreach my $_element (@{$hash->{$_json_attribute}}) {
                push @_array, $self->_deserialize($_subclass, $_element);
            }
            $self->{$_key} = \@_array;
        } elsif (exists $hash->{$_json_attribute}) { #hash(model), primitive, datetime
            $self->{$_key} = $self->_deserialize($_type, $hash->{$_json_attribute});
        } else {
        	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
        }
    }

    return $self;
}

# deserialize non-array data
sub _deserialize {
    my ($self, $type, $data) = @_;
    $log->debugf("deserializing %s with %s",Dumper($data), $type);

    if ($type eq 'DateTime') {
        return DateTime->from_epoch(epoch => str2time($data));
    } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
        return $data;
    } else { # hash(model)
        my $_instance = eval "AsposeCellsCloud::Object::$type->new()";
        return $_instance->from_hash($data);
    }
}


__PACKAGE__->class_documentation({description => '',
                                  class => 'BatchSplitRequest',
                                  required => [], # TODO
}                                 );


__PACKAGE__->method_documentation({
     'source_folder' => {
     	datatype => 'string',
     	base_name => 'SourceFolder',
     	description => 'The directory stores files that need to format conversion.            ',
     	format => '',
     	read_only => '',
     		},
     'source_storage' => {
     	datatype => 'string',
     	base_name => 'SourceStorage',
     	description => 'Aspose Cloud storage name',
     	format => '',
     	read_only => '',
     		},
     'match_condition' => {
     	datatype => 'MatchConditionRequest',
     	base_name => 'MatchCondition',
     	description => 'Indicates the match condition that needs to be processed for the file name.',
     	format => '',
     	read_only => '',
     		},
     'format' => {
     	datatype => 'string',
     	base_name => 'Format',
     	description => 'Output file format',
     	format => '',
     	read_only => '',
     		},
     'from_index' => {
     	datatype => 'int',
     	base_name => 'FromIndex',
     	description => 'From worksheet index of workbook.',
     	format => '',
     	read_only => '',
     		},
     'to_index' => {
     	datatype => 'int',
     	base_name => 'ToIndex',
     	description => 'To worksheet index of workbook.',
     	format => '',
     	read_only => '',
     		},
     'out_folder' => {
     	datatype => 'string',
     	base_name => 'OutFolder',
     	description => 'The directory that stores files whose format conversion was successful.',
     	format => '',
     	read_only => '',
     		},
     'out_storage' => {
     	datatype => 'string',
     	base_name => 'OutStorage',
     	description => 'Aspose Cloud storage name.',
     	format => '',
     	read_only => '',
     		},
     'save_options' => {
     	datatype => 'SaveOptions',
     	base_name => 'SaveOptions',
     	description => 'Indicates save options.',
     	format => '',
     	read_only => '',
     		},    
});

__PACKAGE__->swagger_types( {
    'source_folder' => 'string',
    'source_storage' => 'string',
    'match_condition' => 'MatchConditionRequest',
    'format' => 'string',
    'from_index' => 'int',
    'to_index' => 'int',
    'out_folder' => 'string',
    'out_storage' => 'string',
    'save_options' => 'SaveOptions' 
} );

__PACKAGE__->attribute_map( {
    'source_folder' => 'SourceFolder',
    'source_storage' => 'SourceStorage',
    'match_condition' => 'MatchCondition',
    'format' => 'Format',
    'from_index' => 'FromIndex',
    'to_index' => 'ToIndex',
    'out_folder' => 'OutFolder',
    'out_storage' => 'OutStorage',
    'save_options' => 'SaveOptions' 
} );

__PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});


1;
